# Test Coverage Report

Generated: Tue 2013-05-21 16:43 CEST

| Statements
--- | ---
Module | total | executed | excluded | % covered
Total | 59 | 42 | 16 | 97.7%
hero_slider.__init__ | 1 | 1 | 0 | 100.0%
hero_slider.models | 31 | 23 | 7 | 95.8%
hero_slider.simple_translate | 3 | 1 | 2 | 100.0%
hero_slider.templatetags.hero_slider_tags | 7 | 5 | 2 | 100.0%
hero_slider.tests.test_app.models | 3 | 2 | 1 | 100.0%
hero_slider.views | 14 | 10 | 4 | 100.0%

Excluded packages and modules
Error packages and modules